//
//  AlertView.m
//  UIalertView
//
//  Created by apple on 16/5/10.
//  Copyright © 2016年 apple. All rights reserved.
//

#import "AlertView.h"
#define ScreenWidth [UIScreen mainScreen].bounds.size.width
#define ScreenHeight [UIScreen mainScreen].bounds.size.height
#define ScreenBounds [UIScreen mainScreen].bounds
#define RGBA(r,g,b,a) [UIColor colorWithRed:r/255.0f green:g/255.0f blue:b/255.0f alpha:a]
#define RGB(r,g,b) RGBA(r,g,b,1.0f)

@interface AlertView()<UITableViewDataSource,UITableViewDelegate>

@property(nonatomic,strong)UILabel *titleLabel;
@property(nonatomic,strong)UITableView *tableView;
@property(nonatomic,strong)UIView *backView;

@end

@implementation AlertView

+(id)GlodeBottomView{
    return [self new];
}

-(void)show{
    UIWindow *current = [UIApplication sharedApplication].keyWindow;
    self.backgroundColor = RGBA(0, 0, 0, 0.2);
    [current addSubview:self];
    
    [UIView animateWithDuration:0.3 animations:^{
        [UIView setAnimationCurve:(UIViewAnimationCurveEaseOut)];
        self.backView.frame = CGRectMake(50, 0, ScreenWidth-100, ScreenHeight);
    }];
}

#pragma mark - 懒加载
-(UIView*)backView{
    if (_backView == nil) {
        self.backView = [UIView new];
        _backView.bounds = CGRectMake(50, 0, ScreenWidth-100, ScreenHeight);
        [self addSubview:_backView];
    }
    return _backView;
}

-(UILabel*)titleLabel{
    if (_titleLabel == nil) {
        self.titleLabel = [UILabel new];
        _titleLabel.bounds = CGRectMake(50, 0, ScreenWidth - 100, ScreenHeight);
        _titleLabel.font = [UIFont systemFontOfSize:15];
        _titleLabel.textColor = RGB(83, 83, 83);
        [_backView addSubview:_titleLabel];
    }
    return _titleLabel;
}

-(void)setTitleArray:(NSArray *)titleArray{
    _titleArray = titleArray;
    if (titleArray.count * 50 >= (ScreenHeight *3/4)) {
        self.backView.frame = CGRectMake(50, ScreenHeight *1/3, ScreenWidth-100, ScreenHeight);
        
        self.tableView.frame = CGRectMake(50, ScreenHeight *1/3-150, ScreenWidth-100, ScreenHeight *3/4);
        self.titleLabel.center = CGPointMake(ScreenWidth/2, ScreenHeight *1/3);
        
    }else{
        self.backView.frame = CGRectMake(50, ScreenHeight -  titleArray.count * 50, ScreenWidth-100, ScreenHeight);
        
        self.tableView.frame = CGRectMake(50, ScreenHeight -  self.titleArray.count * 50 , ScreenWidth-100, titleArray.count * 50);
        self.titleLabel.center = CGPointMake(ScreenWidth/2, ScreenHeight -  titleArray.count * 50);
    }

}

-(void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event{
    [self dissMIssView];
}
-(void)willMoveToSuperview:(UIView *)newSuperview{
    self.frame = ScreenBounds;
    [self setUpCellSeparatorInset];
}
- (void)setUpCellSeparatorInset
{
//    if ([self.tableView respondsToSelector:@selector(setSeparatorInset:)]) {
//        [self.tableView setSeparatorInset:UIEdgeInsetsZero];
//    }
//    if ([self.tableView respondsToSelector:@selector(setLayoutMargins:)]) {
//        [self.tableView setLayoutMargins:UIEdgeInsetsZero];
//    }
}

-(void)dissMIssView{
 [UIView animateWithDuration:0.3 animations:^{
     [UIView setAnimationCurve:(UIViewAnimationCurveEaseIn)];
     self.backView.frame = CGRectMake(50, ScreenHeight, ScreenWidth-100, ScreenHeight);
}completion:^(BOOL finished) {
    [self removeFromSuperview];
   }];
}

#pragma UITableView-delegate

-(UITableView*)tableView{
    if (_tableView == nil) {
        self.tableView = [[UITableView alloc] initWithFrame:CGRectMake(50, 0, ScreenWidth-100, ScreenHeight) style:UITableViewStylePlain];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        [self.backView addSubview:_tableView];
    }
    return _tableView;
}

-(UITableViewCell*)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"cell"];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:(UITableViewCellStyleDefault) reuseIdentifier:@"cell"];
    }
    cell.textLabel.text = _titleArray[indexPath.row];
    cell.textLabel.frame = CGRectMake(50, 0, ScreenWidth-100, ScreenHeight);
    
    if (indexPath.row%2==0 ) {
        cell.backgroundColor = [UIColor whiteColor];

    }else{
        cell.backgroundColor = RGB(242, 242, 242);
    }
    return cell;
}

-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return self.titleArray.count;
}

-(CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return 50;
}

-(CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section{
    return 100;
}
-(UIView*)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section{
    UIView *view = [[UIView alloc] initWithFrame:CGRectMake(50, 0, ScreenWidth-100, 100)];
    view.backgroundColor = [UIColor whiteColor];
    [self.backView addSubview:view];
    UIButton *bt = [[UIButton alloc] initWithFrame:CGRectMake(ScreenWidth/2-100, 40, 100, 30)];
    [bt setTitle:@"确定" forState:(UIControlStateNormal)];
    [bt setTitleColor:RGB(83, 83, 83) forState:(UIControlStateNormal)];
    [bt addTarget:self action:@selector(BT:) forControlEvents:(UIControlEventTouchUpInside)];
    bt.layer.borderColor = RGB(83, 83, 83).CGColor;
    bt.layer.masksToBounds = YES;
    bt.layer.cornerRadius = 4;
    [bt.layer setBorderWidth:1.0];

    [view addSubview:bt];
    return view;
}

-(void)BT:(UIButton*)bt{
    [self dissMIssView];
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    if ([self.delegate respondsToSelector:@selector(clickButton:)]) {
        [self.delegate clickButton:indexPath.row];
    }if (self.GlodeBottomView) {
        self.GlodeBottomView(indexPath.row,self.titleArray[indexPath.row]);
    }
    [self dissMIssView];
}

//- (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath
//{
//    if ([cell respondsToSelector:@selector(setSeparatorInset:)]) {
//        [cell setSeparatorInset:UIEdgeInsetsMake(0,0,0,0)];
//    }
//    
//    if ([cell respondsToSelector:@selector(setLayoutMargins:)]) {
//        [cell setLayoutMargins:UIEdgeInsetsMake(0,0,0,0)];
//    }
//}


@end
